Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1255)

Unified Diff: content/public/android/java/src/org/chromium/content/browser/ContentViewClient.java

Issue 2106753004: Introduce bottom controls to CC and let it respond to scrolling (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: content-offset -> top-controls-shown renaming and respond to bokan's comments Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/android/java/src/org/chromium/content/browser/ContentViewClient.java
diff --git a/content/public/android/java/src/org/chromium/content/browser/ContentViewClient.java b/content/public/android/java/src/org/chromium/content/browser/ContentViewClient.java
index a365740d33cf2b5efc4a18bcfde39d8794c092f5..9ce5c3497f3d1fb6ad603dc484f1ab8824bbb3bd 100644
--- a/content/public/android/java/src/org/chromium/content/browser/ContentViewClient.java
+++ b/content/public/android/java/src/org/chromium/content/browser/ContentViewClient.java
@@ -44,11 +44,17 @@ public class ContentViewClient {
/**
* Notifies the client that the position of the top controls has changed.
* @param topControlsOffsetYPix The Y offset of the top controls in physical pixels.
* @param contentOffsetYPix The Y offset of the content in physical pixels.
*/
- public void onOffsetsForFullscreenChanged(
- float topControlsOffsetYPix, float contentOffsetYPix) { }
+ public void onTopControlsChanged(float topBarTranslate, float topBarShown) { }
+
+ /**
+ * Notifies the client that the position of the bottom bar has changed.
+ * @param bottomBarTranslate The Y offset of the bottom controls in physical pixels.
+ * @param bottomBarShown The Y offset of the content in physical pixels.
+ */
+ public void onBottomControlsChanged(float bottomBarTranslate, float bottomBarShown) { }
public boolean shouldOverrideKeyEvent(KeyEvent event) {
int keyCode = event.getKeyCode();
@@ -44,11 +44,17 @@ public class ContentViewClient {
/**
* Notifies the client that the position of the top controls has changed.
- * @param topControlsOffsetYPix The Y offset of the top controls in physical pixels.
- * @param contentOffsetYPix The Y offset of the content in physical pixels.
+ * @param topBarTranslate The Y offset of the top controls in physical pixels.
+ * @param topBarShown The Y offset of the content in physical pixels.
*/

Powered by Google App Engine
This is Rietveld 408576698